@@ -3,7 +3,7 @@ package WebService::PivotalTracker::PropertyAttributes;
 use strict;
 use warnings;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use Scalar::Util qw( blessed );
 use Sub::Quote qw( quote_sub );
@@ -49,7 +49,7 @@ EOF
     }
 
     if ( $prop->{inflator} ) {
-        $default .= sprintf( <<'EOF', $prop->{inflator}, $name );
+        $default .= sprintf( <<'EOF', $prop->{inflator} );
 return unless defined $val;
 return $_[0]->%s( $val );
 EOF
@@ -65,6 +65,7 @@ EOF
         init_arg => undef,
         lazy     => 1,
         default  => quote_sub( $subname, $default, \%env ),
+        clearer  => '_clear_' . $name,
     );
 }
 
